.. _Diagrams:

********
Diagrams
********

Use case diagram
================

.. image:: _static/images/diagrams/diag1.png

.. raw:: latex

    \newpage

Sequence diagram authorization (create-join)
============================================

.. image:: _static/images/diagrams/diag2.png


.. raw:: latex

    \newpage
    
Sequence diagram authentication
===============================

.. image:: _static/images/diagrams/diag3.png

.. raw:: latex

    \newpage
    
Sequence diagram (conversation)
===============================

.. image:: _static/images/diagrams/diag4.png

.. raw:: latex

    \newpage
    
Sequence diagram (exit)
=======================

.. image:: _static/images/diagrams/diag5.png
  
